@@ -25,12 +25,12 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_elasticloadbalancingv2
-import aws_cdk.aws_lambda
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_67de8e8d
+import aws_cdk.aws_elasticloadbalancingv2 as _aws_cdk_aws_elasticloadbalancingv2_e93c784f
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
 
 
-@jsii.implements(aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
+@jsii.implements(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkLoadBalancerTarget)
 class AlbArnTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.AlbArnTarget",
@@ -55,9 +55,7 @@ class AlbArnTarget(
         :param port: The port on which the target is listening.
         '''
         if __debug__:
-            def stub(alb_arn: builtins.str, port: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__21755603a31cc938e8e91cb63fc38c5f8fc7ccf9398b6673d6e6fd80cef9afb3)
             check_type(argname="argument alb_arn", value=alb_arn, expected_type=type_hints["alb_arn"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [alb_arn, port])
@@ -65,8 +63,8 @@ class AlbArnTarget(
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
         self,
-        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+    ) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps:
         '''Register this alb target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
@@ -75,13 +73,9 @@ class AlbArnTarget(
         :param target_group: -
         '''
         if __debug__:
-            def stub(
-                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7c870055ca51103637ed10001392cc6a39ea3c2c6eb247b8f2e609df4024904a)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
 class AlbTarget(
@@ -132,7 +126,7 @@ class AlbTarget(
 
     def __init__(
         self,
-        alb: aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
+        alb: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.ApplicationLoadBalancer,
         port: jsii.Number,
     ) -> None:
         '''
@@ -140,18 +134,13 @@ class AlbTarget(
         :param port: The port on which the target is listening.
         '''
         if __debug__:
-            def stub(
-                alb: aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
-                port: jsii.Number,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7746430c274e9478a37a49023fe1a79dca60e73e110bf0b07255aba94be89d6b)
             check_type(argname="argument alb", value=alb, expected_type=type_hints["alb"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [alb, port])
 
 
-@jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
+@jsii.implements(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationLoadBalancerTarget, _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkLoadBalancerTarget)
 class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceIdTarget",
@@ -183,12 +172,7 @@ class InstanceIdTarget(
         :param port: Override the default port for the target group.
         '''
         if __debug__:
-            def stub(
-                instance_id: builtins.str,
-                port: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7df06609f12197bd945c63619c4d8f0e808634a8ffc2a3eef4363e7bfc6c23d7)
             check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [instance_id, port])
@@ -196,8 +180,8 @@ class InstanceIdTarget(
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
         self,
-        target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
-    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationTargetGroup,
+    ) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps:
         '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
@@ -206,19 +190,15 @@ class InstanceIdTarget(
         :param target_group: -
         '''
         if __debug__:
-            def stub(
-                target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bfb534c3f1f9d7ff3b24bb6195ec02ae558bede6b53ed337db640c51de4e408d)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
         self,
-        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+    ) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps:
         '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
@@ -227,13 +207,9 @@ class InstanceIdTarget(
         :param target_group: -
         '''
         if __debug__:
-            def stub(
-                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f0b2386ecc3bb4ddc5d926a6639c1828bbc7b92fa91b4f341587e7ef08427b9c)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
 class InstanceTarget(
@@ -258,7 +234,7 @@ class InstanceTarget(
 
     def __init__(
         self,
-        instance: aws_cdk.aws_ec2.Instance,
+        instance: _aws_cdk_aws_ec2_67de8e8d.Instance,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
         '''Create a new Instance target.
@@ -267,18 +243,13 @@ class InstanceTarget(
         :param port: Override the default port for the target group.
         '''
         if __debug__:
-            def stub(
-                instance: aws_cdk.aws_ec2.Instance,
-                port: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__74280f986b4c3d46fed198aefaa7d4751a28cda3fe1ebf04baa124ea60fff6f1)
             check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [instance, port])
 
 
-@jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
+@jsii.implements(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationLoadBalancerTarget, _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkLoadBalancerTarget)
 class IpTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.IpTarget",
@@ -332,13 +303,7 @@ class IpTarget(
         :param availability_zone: Availability zone to send traffic from.
         '''
         if __debug__:
-            def stub(
-                ip_address: builtins.str,
-                port: typing.Optional[jsii.Number] = None,
-                availability_zone: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1a6e34c86e5621d2cdf49c460552134f4f1e3d65a5db9f0255f6926a880fa86a)
             check_type(argname="argument ip_address", value=ip_address, expected_type=type_hints["ip_address"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
             check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
@@ -347,8 +312,8 @@ class IpTarget(
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
         self,
-        target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
-    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationTargetGroup,
+    ) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps:
         '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
@@ -357,19 +322,15 @@ class IpTarget(
         :param target_group: -
         '''
         if __debug__:
-            def stub(
-                target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__538fbf7b0b3e47754c98a7bc0dd24dfc247b02d657b261a72565051e81586b17)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
         self,
-        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+    ) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps:
         '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
@@ -378,16 +339,12 @@ class IpTarget(
         :param target_group: -
         '''
         if __debug__:
-            def stub(
-                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__df2f08ba4edd832789927a3c8b564fbaca97c48581cb93d5284dba9459ae6990)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
-@jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget)
+@jsii.implements(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationLoadBalancerTarget)
 class LambdaTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.LambdaTarget",
@@ -416,23 +373,21 @@ class LambdaTarget(
         )
     '''
 
-    def __init__(self, fn: aws_cdk.aws_lambda.IFunction) -> None:
+    def __init__(self, fn: _aws_cdk_aws_lambda_5443dbc3.IFunction) -> None:
         '''Create a new Lambda target.
 
         :param fn: -
         '''
         if __debug__:
-            def stub(fn: aws_cdk.aws_lambda.IFunction) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0a5760cb3aa2f74eca1347dd70774e052da1f440c8b8d4fcbb42b1aee9903c5c)
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         jsii.create(self.__class__, self, [fn])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
         self,
-        target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
-    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationTargetGroup,
+    ) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps:
         '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
@@ -441,19 +396,15 @@ class LambdaTarget(
         :param target_group: -
         '''
         if __debug__:
-            def stub(
-                target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bfc61ad2cb136d67c9d9e6a6e59d4966d27b1bdc071ddcbb70e229d5a78fd84d)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
         self,
-        target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-    ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
+        target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+    ) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps:
         '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
@@ -462,13 +413,9 @@ class LambdaTarget(
         :param target_group: -
         '''
         if __debug__:
-            def stub(
-                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e19af64262f9717f85fe9862d3547d4be9b07533278732d22e6986f72a9a1e84)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
 __all__ = [
@@ -481,3 +428,87 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__21755603a31cc938e8e91cb63fc38c5f8fc7ccf9398b6673d6e6fd80cef9afb3(
+    alb_arn: builtins.str,
+    port: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7c870055ca51103637ed10001392cc6a39ea3c2c6eb247b8f2e609df4024904a(
+    target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7746430c274e9478a37a49023fe1a79dca60e73e110bf0b07255aba94be89d6b(
+    alb: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.ApplicationLoadBalancer,
+    port: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7df06609f12197bd945c63619c4d8f0e808634a8ffc2a3eef4363e7bfc6c23d7(
+    instance_id: builtins.str,
+    port: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bfb534c3f1f9d7ff3b24bb6195ec02ae558bede6b53ed337db640c51de4e408d(
+    target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationTargetGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f0b2386ecc3bb4ddc5d926a6639c1828bbc7b92fa91b4f341587e7ef08427b9c(
+    target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__74280f986b4c3d46fed198aefaa7d4751a28cda3fe1ebf04baa124ea60fff6f1(
+    instance: _aws_cdk_aws_ec2_67de8e8d.Instance,
+    port: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1a6e34c86e5621d2cdf49c460552134f4f1e3d65a5db9f0255f6926a880fa86a(
+    ip_address: builtins.str,
+    port: typing.Optional[jsii.Number] = None,
+    availability_zone: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__538fbf7b0b3e47754c98a7bc0dd24dfc247b02d657b261a72565051e81586b17(
+    target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationTargetGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__df2f08ba4edd832789927a3c8b564fbaca97c48581cb93d5284dba9459ae6990(
+    target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0a5760cb3aa2f74eca1347dd70774e052da1f440c8b8d4fcbb42b1aee9903c5c(
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bfc61ad2cb136d67c9d9e6a6e59d4966d27b1bdc071ddcbb70e229d5a78fd84d(
+    target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationTargetGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e19af64262f9717f85fe9862d3547d4be9b07533278732d22e6986f72a9a1e84(
+    target_group: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkTargetGroup,
+) -> None:
+    """Type checking stubs"""
+    pass
